package com.cpms.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cpms.project.plant.mapper.TMtContentMapper;
import com.cpms.project.plant.domain.TMtContent;
import com.cpms.project.plant.service.ITMtContentService;

/**
 * 装置空白会议Service业务层处理
 *
 * @author ruoyi
 * @date 2023-08-03
 */
@Service
public class TMtContentServiceImpl implements ITMtContentService
{
    @Autowired
    private TMtContentMapper tMtContentMapper;

    /**
     * 查询装置空白会议
     *
     * @param id 装置空白会议主键
     * @return 装置空白会议
     */
    @Override
    public TMtContent selectTMtContentById(Long id)
    {
        return tMtContentMapper.selectTMtContentById(id);
    }

    /**
     * 查询装置空白会议列表
     *
     * @param tMtContent 装置空白会议
     * @return 装置空白会议
     */
    @Override
    public List<TMtContent> selectTMtContentList(TMtContent tMtContent)
    {
        return tMtContentMapper.selectTMtContentList(tMtContent);
    }    @Override
    public List<TMtContent> selectContentList(TMtContent tMtContent)
    {
        return tMtContentMapper.selectContentList(tMtContent);
    }

    /**
     * 新增装置空白会议
     *
     * @param tMtContent 装置空白会议
     * @return 结果
     */
    @Override
    public int insertTMtContent(TMtContent tMtContent)
    {
        return tMtContentMapper.insertTMtContent(tMtContent);
    }

    /**
     * 修改装置空白会议
     *
     * @param tMtContent 装置空白会议
     * @return 结果
     */
    @Override
    public int updateTMtContent(TMtContent tMtContent)
    {
        return tMtContentMapper.updateTMtContent(tMtContent);
    }

    /**
     * 批量删除装置空白会议
     *
     * @param ids 需要删除的装置空白会议主键
     * @return 结果
     */
    @Override
    public int deleteTMtContentByIds(Long[] ids)
    {
        return tMtContentMapper.deleteTMtContentByIds(ids);
    }

    /**
     * 删除装置空白会议信息
     *
     * @param id 装置空白会议主键
     * @return 结果
     */
    @Override
    public int deleteTMtContentById(Long id)
    {
        return tMtContentMapper.deleteTMtContentById(id);
    }
}
